# residue_to_value example

This example shows how to use the residue_to_value protocol. Targets are given as floats or ints, separated by ";".

Execute the example (from the base directory):
```bash
biotrainer train --config examples/residue_to_value/config.yml
```
